@@ -17,9 +17,7 @@ pub use self::headers::Headers;
 pub use self::value::Value;
 pub use self::untils::tool::Tool;
 
-pub use select;
+
 pub use dbfile;
 pub use dbfile_derive;
-pub use postgres;
-pub use rusqlite;
-pub use regex;
+pub use {rusqlite, regex, postgres, select};
